WindowAttributesMacOS

Struct WindowAttributesMacOS 

pub struct WindowAttributesMacOS { /* private fields */ }
Window attributes that are specific to MacOS.

Note: Properties dealing with the titlebar will be overwritten by the WindowAttributes::with_decorations method:

  • with_titlebar_transparent
  • with_title_hidden
  • with_titlebar_hidden
  • with_titlebar_buttons_hidden
  • with_fullsize_content_view

Implementations

Source

impl WindowAttributesMacOS

pub fn with_movable_by_window_background( self, movable_by_window_background: bool, ) -> Self

Enables click-and-drag behavior for the entire window, not just the titlebar.

pub fn with_blur_material(self, blur_material: BlurMaterial) -> Self

Sets the material drawn behind the window when it is blurred.

Has no effect unless the window is blurred, see Window::set_blur.

pub fn with_titlebar_transparent(self, titlebar_transparent: bool) -> Self

Makes the titlebar transparent and allows the content to appear behind it.

pub fn with_titlebar_hidden(self, titlebar_hidden: bool) -> Self

Hides the window titlebar.

pub fn with_titlebar_buttons_hidden(self, titlebar_buttons_hidden: bool) -> Self

Hides the window titlebar buttons.

pub fn with_title_hidden(self, title_hidden: bool) -> Self

Hides the window title.

pub fn with_fullsize_content_view(self, fullsize_content_view: bool) -> Self

Makes the window content appear behind the titlebar.

pub fn with_disallow_hidpi(self, disallow_hidpi: bool) -> Self

pub fn with_has_shadow(self, has_shadow: bool) -> Self

pub fn with_tabbing_identifier(self, tabbing_identifier: &str) -> Self

pub fn with_option_as_alt(self, option_as_alt: OptionAsAlt) -> Self

Set how the Option keys are interpreted.

See WindowExtMacOS::set_option_as_alt for details on what this means if set.

pub fn with_borderless_game(self, borderless_game: bool) -> Self

See WindowExtMacOS::set_borderless_game for details on what this means if set.

pub fn with_unified_titlebar(self, unified_titlebar: bool) -> Self

See WindowExtMacOS::set_unified_titlebar for details on what this means if set.

pub fn with_panel(self, panel: bool) -> Self

Use NSPanel window with NonactivatingPanel window style mask instead of NSWindow.

pub fn with_fullscreen_auxiliary(self, fullscreen_auxiliary: bool) -> Self

See WindowExtMacOS::set_fullscreen_auxiliary for details on what this means if set.

Contrary to the runtime setter, setting this attribute guarantees that the collection behavior is already in place when the window is first ordered on screen, which is required to avoid disturbing an active fullscreen Space.