pub struct WindowAttributesMacOS { /* private fields */ }Expand description
Window attributes that are specific to MacOS.
Note: Properties dealing with the titlebar will be overwritten by the
WindowAttributes::with_decorations method:
with_titlebar_transparentwith_title_hiddenwith_titlebar_hiddenwith_titlebar_buttons_hiddenwith_fullsize_content_view
Implementations
Sourceimpl WindowAttributesMacOS
impl WindowAttributesMacOS
Sourcepub fn with_movable_by_window_background(
self,
movable_by_window_background: bool,
) -> Self
pub fn with_movable_by_window_background( self, movable_by_window_background: bool, ) -> Self
Enables click-and-drag behavior for the entire window, not just the titlebar.
Sourcepub fn with_blur_material(self, blur_material: BlurMaterial) -> Self
pub fn with_blur_material(self, blur_material: BlurMaterial) -> Self
Sets the material drawn behind the window when it is blurred.
Has no effect unless the window is blurred, see Window::set_blur.
Sourcepub fn with_titlebar_transparent(self, titlebar_transparent: bool) -> Self
pub fn with_titlebar_transparent(self, titlebar_transparent: bool) -> Self
Makes the titlebar transparent and allows the content to appear behind it.
Hides the window titlebar.
Hides the window titlebar buttons.
Hides the window title.
Sourcepub fn with_fullsize_content_view(self, fullsize_content_view: bool) -> Self
pub fn with_fullsize_content_view(self, fullsize_content_view: bool) -> Self
Makes the window content appear behind the titlebar.
pub fn with_disallow_hidpi(self, disallow_hidpi: bool) -> Self
pub fn with_has_shadow(self, has_shadow: bool) -> Self
Sourcepub fn with_tabbing_identifier(self, tabbing_identifier: &str) -> Self
pub fn with_tabbing_identifier(self, tabbing_identifier: &str) -> Self
Defines the window tabbing identifier.
https://developer.apple.com/documentation/appkit/nswindow/1644704-tabbingidentifier
Sourcepub fn with_option_as_alt(self, option_as_alt: OptionAsAlt) -> Self
pub fn with_option_as_alt(self, option_as_alt: OptionAsAlt) -> Self
Set how the Option keys are interpreted.
See WindowExtMacOS::set_option_as_alt for details on what this means if set.
Sourcepub fn with_borderless_game(self, borderless_game: bool) -> Self
pub fn with_borderless_game(self, borderless_game: bool) -> Self
See WindowExtMacOS::set_borderless_game for details on what this means if set.
Sourcepub fn with_unified_titlebar(self, unified_titlebar: bool) -> Self
pub fn with_unified_titlebar(self, unified_titlebar: bool) -> Self
See WindowExtMacOS::set_unified_titlebar for details on what this means if set.
Sourcepub fn with_panel(self, panel: bool) -> Self
pub fn with_panel(self, panel: bool) -> Self
Use NSPanel window with NonactivatingPanel window style mask instead of
NSWindow.
Sourcepub fn with_fullscreen_auxiliary(self, fullscreen_auxiliary: bool) -> Self
pub fn with_fullscreen_auxiliary(self, fullscreen_auxiliary: bool) -> Self
See WindowExtMacOS::set_fullscreen_auxiliary for details on what this means if set.
Contrary to the runtime setter, setting this attribute guarantees that the collection behavior is already in place when the window is first ordered on screen, which is required to avoid disturbing an active fullscreen Space.